@@ -1,15 +1,23 @@
 import importlib
 import inspect
 import os
+import re
 import secrets
 import sys
 import textwrap
+from dataclasses import dataclass
 from types import FunctionType
+from typing import Any, Optional
 
 import pytest
 from _pytest.assertion.rewrite import AssertionRewritingHook
 
 
+def pytest_addoption(parser):
+    parser.addoption('--test-mypy', action='store_true', help='run mypy tests')
+    parser.addoption('--update-mypy', action='store_true', help='update mypy tests')
+
+
 def _extract_source_code_from_function(function):
     if function.__code__.co_argcount:
         raise RuntimeError(f'function {function.__qualname__} cannot have any arguments')
@@ -33,26 +41,11 @@ def _create_module_file(code, tmp_path, name):
     return name, str(path)
 
 
-class SetEnv:
-    def __init__(self):
-        self.envars = set()
-
-    def set(self, name, value):
-        self.envars.add(name)
-        os.environ[name] = value
-
-    def clear(self):
-        for n in self.envars:
-            os.environ.pop(n)
-
-
-@pytest.yield_fixture
-def env():
-    setenv = SetEnv()
-
-    yield setenv
-
-    setenv.clear()
+@pytest.fixture(scope='session', autouse=True)
+def disable_error_urls():
+    # Don't add URLs during docs tests when printing
+    # Otherwise we'll get version numbers in the URLs that will update frequently
+    os.environ['PYDANTIC_ERRORS_OMIT_URL'] = 'true'
 
 
 @pytest.fixture
@@ -85,3 +78,18 @@ def create_module(tmp_path, request):
         return module
 
     return run
+
+
+@dataclass
+class Err:
+    message: str
+    errors: Optional[Any] = None
+
+    def __repr__(self):
+        if self.errors:
+            return f'Err({self.message!r}, errors={self.errors!r})'
+        else:
+            return f'Err({self.message!r})'
+
+    def message_escaped(self):
+        return re.escape(self.message)
