@@ -1,7 +1,7 @@
 import random
 import sys
 from abc import ABC, abstractmethod
-from typing import Any, Callable, ClassVar, List, Tuple
+from typing import Any, Callable, ClassVar, Generic, List, Tuple, TypeVar
 
 import pytest
 from pydantic_core import ValidationError, core_schema
@@ -15,6 +15,7 @@ from pydantic import (
     TypeAdapter,
     computed_field,
     dataclasses,
+    field_serializer,
     field_validator,
 )
 from pydantic.alias_generators import to_camel
@@ -119,14 +120,23 @@ def test_computed_fields_set():
         def area(self) -> float:
             return self.side**2
 
+        @computed_field
+        @property
+        def area_string(self) -> str:
+            return f'{self.area} square units'
+
+        @field_serializer('area_string')
+        def serialize_area_string(self, area_string):
+            return area_string.upper()
+
         @area.setter
         def area(self, new_area: int):
             self.side = new_area**0.5
 
     s = Square(side=10)
-    assert s.model_dump() == {'side': 10.0, 'area': 100.0}
+    assert s.model_dump() == {'side': 10.0, 'area': 100.0, 'area_string': '100.0 SQUARE UNITS'}
     s.area = 64
-    assert s.model_dump() == {'side': 8.0, 'area': 64.0}
+    assert s.model_dump() == {'side': 8.0, 'area': 64.0, 'area_string': '64.0 SQUARE UNITS'}
 
 
 def test_computed_fields_del():
@@ -707,3 +717,27 @@ def test_multiple_references_to_schema(model_factory: Callable[[], Any]) -> None
         'title': 'Model',
         'type': 'object',
     }
+
+
+def test_generic_computed_field():
+    T = TypeVar('T')
+
+    class A(BaseModel, Generic[T]):
+        x: T
+
+        @computed_field
+        @property
+        def double_x(self) -> T:
+            return self.x * 2
+
+    assert A[int](x=1).model_dump() == {'x': 1, 'double_x': 2}
+    assert A[str](x='abc').model_dump() == {'x': 'abc', 'double_x': 'abcabc'}
+
+    class B(BaseModel, Generic[T]):
+        @computed_field
+        @property
+        def double_x(self) -> T:
+            return 'abc'  # this may not match the annotated return type, and will warn if not
+
+    with pytest.warns(UserWarning, match='Expected `int` but got `str` - serialized value may not be as expected'):
+        B[int]().model_dump()
